@@ -26,7 +26,7 @@ class BaseLog:
 
     log_levels = ['info', 'debug', 'warn', 'error']
 
-    def __init__(self, app_name, prefix_path, f_code, t_code, when="D", backup_count=3,
+    def __init__(self, app_name, prefix_path, t_code, f_code="", when="D", backup_count=3,
                  journal_log_enable=True):
         if not os.path.exists(prefix_path):
             os.mkdir(prefix_path)
@@ -36,7 +36,6 @@ class BaseLog:
         self.host_name = socket.gethostname()
         self.generate_loggers(when, backup_count)
         self.journal_log_enable = journal_log_enable
-        self.f_code = f_code
         self.t_code = t_code
 
     def generate_loggers(self, when, backup_count):
@@ -158,7 +157,8 @@ class BaseLog:
                      remark="",
                      method_code="",
                      log_level='INFO',
-                     dialog_type='out'):
+                     dialog_type='out',
+                     f_code=""):
         _, _, _, logger_module = self.get_current_location()
         data = {
             "app_name": self.journal_log_name,  # 服务编号
@@ -168,8 +168,8 @@ class BaseLog:
             "transaction_id": transaction_id,
             "dialog_type": dialog_type,
             "address": request_url,
-            "fcode": self.f_code if dialog_type == 'out' else "",
-            "tcode": self.t_code if dialog_type == 'in' else "",
+            "fcode": f_code if dialog_type == 'out' else self.t_code,
+            "tcode": self.t_code if dialog_type == 'in' else f_code,
             "method_code": method_code,
             "http_method": http_method,
             "request_time": request_time.strftime("%Y-%m-%d %H:%M:%S"),
@@ -188,7 +188,7 @@ class BaseLog:
             "city_code": "",
             "key_type": "",
             "key_param": "",
-            "total_time": total_time,
+            "total_time": str(total_time),
         }
         message = json.dumps(data, ensure_ascii=False)
         logging.getLogger(self.journal_log_name).info(message)
