@@ -88,6 +88,7 @@ class MainLog(BaseLog):
                     end_time = time.time()
                     try:
                         total_time = end_time - begin_time
+                        f_code = request.headers.get('User-Agent')
                         self.debug('with_internal_journallog() connection  after:%s', str(total_time))
                         # 接口前置流水日志处理
                         self.debug('%s Interface start,with param: %s', f.__name__, str(request.args))
@@ -111,6 +112,10 @@ class MainLog(BaseLog):
                                 if not isinstance(str_ret, unicode):
                                     str_ret = unicode(str_ret, 'utf-8')
                                 str_ret = str_ret[:3000]
+                        if request_length > 3000:
+                            if not isinstance(request_content, unicode):
+                                request_content = unicode(request_content, 'utf-8')
+                            request_content = request_content[:3000]
                         response_content = str_ret
                         response_length = len(response_content)  # response正文长度
                         log_head_length = 80
@@ -163,7 +168,8 @@ class MainLog(BaseLog):
                                           total_time=total_time,
                                           order_id=order_id,
                                           phone_num=phone_num,
-                                          method_code=method_code
+                                          method_code=method_code,
+                                          f_code=f_code
                                           )
                     except Exception as ex:
                         self.exception('Internal Journallog write log error, %s', ex.message)
